@@ -1,6 +1,6 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *   Mupen64plus-core - m64p_plugin.h                                      *
- *   Mupen64Plus homepage: http://code.google.com/p/mupen64plus/           *
+ *   Mupen64Plus homepage: https://mupen64plus.org/                        *
  *   Copyright (C) 2002 Hacktarux                                          *
  *   Copyright (C) 2009 Richard Goedeken                                   *
  *                                                                         *
@@ -32,14 +32,10 @@ extern "C" {
 /*** Controller plugin's ****/
 #define PLUGIN_NONE                 1
 #define PLUGIN_MEMPAK               2
-#define PLUGIN_RUMBLE_PAK           3 /* not implemeted for non raw data */
-#define PLUGIN_TANSFER_PAK          4 /* not implemeted for non raw data */
+#define PLUGIN_RUMBLE_PAK           3 /* not implemented for non raw data */
+#define PLUGIN_TRANSFER_PAK         4 /* not implemented for non raw data */
 #define PLUGIN_RAW                  5 /* the controller plugin is passed in raw data */
-
-/*** Audio plugin system types ***/
-#define SYSTEM_NTSC                 0
-#define SYSTEM_PAL                  1
-#define SYSTEM_MPAL                 2
+#define PLUGIN_BIO_PAK              6
 
 /***** Structures *****/
 typedef struct {
@@ -108,6 +104,19 @@ typedef struct {
     unsigned int * VI_Y_SCALE_REG;
 
     void (*CheckInterrupts)(void);
+
+    /* The GFX_INFO.version parameter was added in version 2.5.1 of the core.
+       Plugins should ensure the core is at least this version before
+       attempting to read GFX_INFO.version. */
+    unsigned int version;
+    /* SP_STATUS_REG and RDRAM_SIZE were added in version 2 of GFX_INFO.version.
+       Plugins should only attempt to read these values if GFX_INFO.version is at least 2. */
+
+    /* The RSP plugin should set (HALT | BROKE | TASKDONE) *before* calling ProcessDList.
+       It should not modify SP_STATUS_REG after ProcessDList has returned.
+       This will allow the GFX plugin to unset these bits if it needs. */
+    unsigned int * SP_STATUS_REG;
+    const unsigned int * RDRAM_SIZE;
 } GFX_INFO;
 
 typedef struct {
@@ -130,7 +139,7 @@ typedef struct {
 typedef struct {
     int Present;
     int RawData;
-    int  Plugin;
+    int Plugin;
 } CONTROL;
 
 typedef union {
@@ -184,6 +193,7 @@ typedef void (*ptr_ViStatusChanged)(void);
 typedef void (*ptr_ViWidthChanged)(void);
 typedef void (*ptr_ReadScreen2)(void *dest, int *width, int *height, int front);
 typedef void (*ptr_SetRenderingCallback)(void (*callback)(int));
+typedef void (*ptr_ResizeVideoOutput)(int width, int height);
 #if defined(M64P_PLUGIN_PROTOTYPES)
 EXPORT void CALL ChangeWindow(void);
 EXPORT int  CALL InitiateGFX(GFX_INFO Gfx_Info);
@@ -196,6 +206,7 @@ EXPORT void CALL ViStatusChanged(void);
 EXPORT void CALL ViWidthChanged(void);
 EXPORT void CALL ReadScreen2(void *dest, int *width, int *height, int front);
 EXPORT void CALL SetRenderingCallback(void (*callback)(int));
+EXPORT void CALL ResizeVideoOutput(int width, int height);
 #endif
 
 /* frame buffer plugin spec extension */
@@ -248,6 +259,7 @@ typedef void (*ptr_InitiateControllers)(CONTROL_INFO ControlInfo);
 typedef void (*ptr_ReadController)(int Control, unsigned char *Command);
 typedef void (*ptr_SDL_KeyDown)(int keymod, int keysym);
 typedef void (*ptr_SDL_KeyUp)(int keymod, int keysym);
+typedef void (*ptr_RenderCallback)(void);
 #if defined(M64P_PLUGIN_PROTOTYPES)
 EXPORT void CALL ControllerCommand(int Control, unsigned char *Command);
 EXPORT void CALL GetKeys(int Control, BUTTONS *Keys);
@@ -255,6 +267,7 @@ EXPORT void CALL InitiateControllers(CONTROL_INFO ControlInfo);
 EXPORT void CALL ReadController(int Control, unsigned char *Command);
 EXPORT void CALL SDL_KeyDown(int keymod, int keysym);
 EXPORT void CALL SDL_KeyUp(int keymod, int keysym);
+EXPORT void CALL RenderCallback(void);
 #endif
 
 /* RSP plugin function pointers */
